==> nextcloud-16.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/privacy/l10n/pl.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Prywatność",
    "-" : "-",
    "Add external admin" : "Dodaj zewnętrznego administratora",
    "Your files are not protected by encryption." : "Twoje pliki nie są chronione przez szyfrowanie.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}." : "Twoje pliki są szyfrowane za pomocą {linkopen}server-side-encryption ↗{linkclose}.",
    "This server is protected with full-disk-encryption." : "Ten serwer jest chroniony za pomocą full-disk-encryption.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}. Additionally, this server is protected with full-disk-encryption." : "Twoje pliki są szyfrowane za pomocą {linkopen}server-side-encryption ↗{linkclose}. Ponadto ten serwer jest chroniony za pomocą full-disk-encryption.",
    "This server is using full-disk-encryption." : "Ten serwer używa full-disk-encryption.",
    "Your data is located in: " : "Twoje dane znajdują się w: ",
    "The admin hasn't selected the location of the server yet." : "Administrator nie wybrał jeszcze lokalizacji serwera.",
    "Please select a country" : "Wybierz kraj",
    "You don't have any shares with individual users." : "Nie masz żadnych udostępnień dla poszczególnych użytkowników.",
    "Somaliland" : "Somaliland",
    "United Arab Emirates" : "United Arab Emirates",
    "Afghanistan" : "Afghanistan",
    "Albania" : "Albania",
    "Armenia" : "Armenia",
    "Angola" : "Angola",
    "Argentina" : "Argentina",
    "Austria" : "Austria",
    "Australia" : "Australia",
    "Azerbaijan" : "Azerbaijan",
    "Bosnia and Herzegowina" : "Bosnia and Herzegowina",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Belgium",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgaria",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Brunei" : "Brunei",
    "Bolivia" : "Bolivia",
    "Brazil" : "Brazil",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Bhutan",
    "Botswana" : "Botswana",
    "Belarus" : "Belarus",
    "Belize" : "Belize",
    "Canada" : "Canada",
    "Democratic Republic of the Congo" : "Democratic Republic of the Congo",
    "Central African Republic" : "Central African Republic",
    "Congo" : "Congo",
    "Switzerland" : "Switzerland",
    "Cote d'Ivoire" : "Cote d'Ivoire",
    "Chile" : "Chile",
    "Cameroon" : "Cameroon",
    "China" : "China",
    "Colombia" : "Colombia",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Cuba",
    "Cyprus" : "Cyprus",
    "Czech" : "Czech",
    "Germany" : "Germany",
    "Djibouti" : "Djibouti",
    "Denmark" : "Denmark",
    "Dominican Republic" : "Dominican Republic",
    "Algeria" : "Algeria",
    "Ecuador" : "Ecuador",
    "Estonia" : "Estonia",
    "Egypt" : "Egypt",
    "West Sahara" : "West Sahara",
    "Eritrea" : "Eritrea",
    "Spain" : "Spain",
    "Ethiopia" : "Ethiopia",
    "Finland" : "Finland",
    "Fiji" : "Fiji",
    "Falkland Islands" : "Falkland Islands",
    "France" : "France",
    "Gabon" : "Gabon",
    "United Kingdom" : "United Kingdom",
    "Georgia" : "Georgia",
    "Ghana" : "Ghana",
    "Greenland" : "Greenland",
    "Gambia" : "Gambia",
    "Guinea" : "Guinea",
    "Equatorial Guinea" : "Equatorial Guinea",
    "Greece" : "Greece",
    "Guatemala" : "Guatemala",
    "Guinea-Bissau" : "Guinea-Bissau",
    "Guyana" : "Guyana",
    "Honduras" : "Honduras",
    "Croatia" : "Croatia",
    "Haiti" : "Haiti",
    "Hungary" : "Hungary",
    "Indonesia" : "Indonesia",
    "Ireland" : "Ireland",
    "Israel" : "Israel",
    "India" : "India",
    "Iraq" : "Iraq",
    "Iran" : "Iran",
    "Iceland" : "Iceland",
    "Italy" : "Italy",
    "Jamaica" : "Jamaica",
    "Jordan" : "Jordan",
    "Japan" : "Japan",
    "Kenya" : "Kenya",
    "Kyrgyzstan" : "Kyrgyzstan",
    "Cambodia" : "Cambodia",
    "North Korea" : "North Korea",
    "South Korea" : "South Korea",
    "Kuwait" : "Kuwait",
    "Kazakhstan" : "Kazakhstan",
    "Laos" : "Laos",
    "Lebanon" : "Lebanon",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberia",
    "Lesotho" : "Lesotho",
    "Lithuania" : "Lithuania",
    "Luxembourg" : "Luxembourg",
    "Latvia" : "Latvia",
    "Libya" : "Libya",
    "Morocco" : "Morocco",
    "Moldova" : "Moldova",
    "Montenegro" : "Montenegro",
    "Madagascar" : "Madagascar",
    "Macedonia" : "Macedonia",
    "Mali" : "Mali",
    "Myanmar" : "Myanmar",
    "Mongolia" : "Mongolia",
    "Mauritania" : "Mauritania",
    "Malawi" : "Malawi",
    "Mexico" : "Mexico",
    "Malaysia" : "Malaysia",
    "Mozambique" : "Mozambique",
    "Namibia" : "Namibia",
    "New Caledonia" : "New Caledonia",
    "Niger" : "Niger",
    "Nigeria" : "Nigeria",
    "Nicaragua" : "Nicaragua",
    "Netherlands" : "Netherlands",
    "Norway" : "Norway",
    "Nepal" : "Nepal",
    "New Zealand" : "New Zealand",
    "Oman" : "Oman",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "Papua New Guinea" : "Papua New Guinea",
    "Philippines" : "Philippines",
    "Pakistan" : "Pakistan",
    "Poland" : "Poland",
    "Puerto Rico" : "Puerto Rico",
    "Portugal" : "Portugal",
    "Paraguay" : "Paraguay",
    "Qatar" : "Qatar",
    "Romania" : "Romania",
    "Serbia" : "Serbia",
    "Russia" : "Russia",
    "Rwanda" : "Rwanda",
    "Saudi Arabia" : "Saudi Arabia",
    "Solomon Islands" : "Solomon Islands",
    "Sudan" : "Sudan",
    "Sweden" : "Sweden",
    "Singapore" : "Singapore",
    "Slovenia" : "Slovenia",
    "Slovakia" : "Slovakia",
    "Sierra Leone" : "Sierra Leone",
    "Senegal" : "Senegal",
    "Somalia" : "Somalia",
    "Suriname" : "Suriname",
    "South Sudan" : "South Sudan",
    "El Salvador" : "El Salvador",
    "Syria" : "Syria",
    "Swaziland" : "Swaziland",
    "Chad" : "Chad",
    "Fr. S. Antarctic Lands" : "Fr. S. Antarctic Lands",
    "Togo" : "Togo",
    "Thailand" : "Thailand",
    "Tajikistan" : "Tajikistan",
    "Timor-Leste" : "Timor-Leste",
    "Turkmenistan" : "Turkmenistan",
    "Tunisia" : "Tunisia",
    "Turkey" : "Turkey",
    "Trinidad and Tobago" : "Trinidad and Tobago",
    "Taiwan" : "Taiwan",
    "Tanzania" : "Tanzania",
    "Ukraine" : "Ukraine",
    "Uganda" : "Uganda",
    "United States" : "United States",
    "Uruguay" : "Uruguay",
    "Uzbekistan" : "Uzbekistan",
    "Venezuela" : "Venezuela",
    "Vietnam" : "Vietnam",
    "Vanuatu" : "Vanuatu",
    "Yemen" : "Yemen",
    "South Africa" : "South Africa",
    "Zambia" : "Zambia",
    "Zimbabwe" : "Zimbabwe",
    "Your Nextcloud account" : "Twoje konto Nextcloud",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "Dane reprezentują Twoją tożsamość i mogą łatwo zostać wykorzystane. W Nextcloud wierzymy, że masz prawo decydować o tym, co dzieje się z Twoimi danymi. Nextcloud chroni Twoje prawa zgodnie z definicją w User Data Manifesto!",
    "User Data Manifesto 2.0" : "User Data Manifesto 2.0",
    "Defining basic rights for people to control their own data in the internet age" : "Określenie podstawowych praw do kontroli własnych danych w dobie internetu",
    "Control" : "Kontrola",
    "over user data access" : "nad dostępem do danych użytkownika",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "Dane jawnie i dobrowolnie przesłane przez użytkownika powinny być pod ostateczną kontrolą użytkownika. Użytkownicy powinni mieć możliwość decydowania, komu przyznać bezpośredni dostęp do swoich danych oraz jakie pozwolenia powinny zostać przyznane.",
    "Knowledge" : "Wiedza",
    "of how the data is stored" : "sposobu przechowywania danych",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "Kiedy dane są przesyłane do określonego usługodawcy, użytkownicy powinni być informowani o tym, gdzie dany dostawca usług przechowuje dane, jak długo, w jakiej jurysdykcji działa dany usługodawca, i które przepisy mają zastosowanie.",
    "Freedom" : "Wolność",
    "to choose a platform" : "wybrać platformę",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "Użytkownicy powinni mieć zawsze możliwość wyodrębnienia swoich danych z usługi w dowolnym czasie, nie mając możliwości zablokowania dostawcy. Aby to zagwarantować, niezbędne są otwarte standardy formatów i protokołów.",
    "Learn more ↗" : "Dowiedz się więcej ↗",
    "Where is your data?" : "Gdzie są Twoje dane?",
    "Who has access to your data?" : "Kto ma dostęp do Twoich danych?",
    "Administrators" : "Administratorzy",
    "People you shared with" : "Osoby, którym udostępniasz",
    "Privacy policy" : "Polityka prywatności",
    "Read the privacy policy." : "Przeczytaj politykę prywatności.",
    "Encryption" : "Szyfrowanie"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");

==> nextcloud-16.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/privacy/l10n/pl.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Prywatność",
    "-" : "-",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "Centrum prywatności pokazuje, gdzie są przechowywane Twoje dane i kto może uzyskać do nich dostęp, ponieważ udostępniłeś je lub jesteś administratorem.",
    "Add external admin" : "Dodaj zewnętrznego administratora",
    "Your files are not protected by encryption." : "Twoje pliki nie są chronione przez szyfrowanie.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}." : "Twoje pliki są szyfrowane za pomocą {linkopen}server-side-encryption ↗{linkclose}.",
    "This server is protected with full-disk-encryption." : "Ten serwer jest chroniony za pomocą full-disk-encryption.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}. Additionally, this server is protected with full-disk-encryption." : "Twoje pliki są szyfrowane za pomocą {linkopen}server-side-encryption ↗{linkclose}. Ponadto ten serwer jest chroniony za pomocą full-disk-encryption.",
    "This server is using full-disk-encryption." : "Ten serwer używa full-disk-encryption.",
    "Your data is located in: " : "Twoje dane znajdują się w: ",
    "The admin hasn't selected the location of the server yet." : "Administrator nie wybrał jeszcze lokalizacji serwera.",
    "Please select a country" : "Wybierz kraj",
    "You don't have any shares with individual users." : "Nie masz żadnych udostępnień dla poszczególnych użytkowników.",
    "Somaliland" : "Somaliland",
    "United Arab Emirates" : "United Arab Emirates",
    "Afghanistan" : "Afghanistan",
    "Albania" : "Albania",
    "Armenia" : "Armenia",
    "Angola" : "Angola",
    "Argentina" : "Argentina",
    "Austria" : "Austria",
    "Australia" : "Australia",
    "Azerbaijan" : "Azerbaijan",
    "Bosnia and Herzegowina" : "Bosnia and Herzegowina",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Belgium",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgaria",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Brunei" : "Brunei",
    "Bolivia" : "Bolivia",
    "Brazil" : "Brazil",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Bhutan",
    "Botswana" : "Botswana",
    "Belarus" : "Belarus",
    "Belize" : "Belize",
    "Canada" : "Canada",
    "Democratic Republic of the Congo" : "Democratic Republic of the Congo",
    "Central African Republic" : "Central African Republic",
    "Congo" : "Congo",
    "Switzerland" : "Switzerland",
    "Cote d'Ivoire" : "Cote d'Ivoire",
    "Chile" : "Chile",
    "Cameroon" : "Cameroon",
    "China" : "China",
    "Colombia" : "Colombia",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Cuba",
    "Cyprus" : "Cyprus",
    "Czech" : "Czech",
    "Germany" : "Germany",
    "Djibouti" : "Djibouti",
    "Denmark" : "Denmark",
    "Dominican Republic" : "Dominican Republic",
    "Algeria" : "Algeria",
    "Ecuador" : "Ecuador",
    "Estonia" : "Estonia",
    "Egypt" : "Egypt",
    "West Sahara" : "West Sahara",
    "Eritrea" : "Eritrea",
    "Spain" : "Spain",
    "Ethiopia" : "Ethiopia",
    "Finland" : "Finland",
    "Fiji" : "Fiji",
    "Falkland Islands" : "Falkland Islands",
    "France" : "France",
    "Gabon" : "Gabon",
    "United Kingdom" : "United Kingdom",
    "Georgia" : "Georgia",
    "Ghana" : "Ghana",
    "Greenland" : "Greenland",
    "Gambia" : "Gambia",
    "Guinea" : "Guinea",
    "Equatorial Guinea" : "Equatorial Guinea",
    "Greece" : "Greece",
    "Guatemala" : "Guatemala",
    "Guinea-Bissau" : "Guinea-Bissau",
    "Guyana" : "Guyana",
    "Honduras" : "Honduras",
    "Croatia" : "Croatia",
    "Haiti" : "Haiti",
    "Hungary" : "Hungary",
    "Indonesia" : "Indonesia",
    "Ireland" : "Ireland",
    "Israel" : "Israel",
    "India" : "India",
    "Iraq" : "Iraq",
    "Iran" : "Iran",
    "Iceland" : "Iceland",
    "Italy" : "Italy",
    "Jamaica" : "Jamaica",
    "Jordan" : "Jordan",
    "Japan" : "Japan",
    "Kenya" : "Kenya",
    "Kyrgyzstan" : "Kyrgyzstan",
    "Cambodia" : "Cambodia",
    "North Korea" : "North Korea",
    "South Korea" : "South Korea",
    "Kuwait" : "Kuwait",
    "Kazakhstan" : "Kazakhstan",
    "Laos" : "Laos",
    "Lebanon" : "Lebanon",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberia",
    "Lesotho" : "Lesotho",
    "Lithuania" : "Lithuania",
    "Luxembourg" : "Luxembourg",
    "Latvia" : "Latvia",
    "Libya" : "Libya",
    "Morocco" : "Morocco",
    "Moldova" : "Moldova",
    "Montenegro" : "Montenegro",
    "Madagascar" : "Madagascar",
    "Macedonia" : "Macedonia",
    "Mali" : "Mali",
    "Myanmar" : "Myanmar",
    "Mongolia" : "Mongolia",
    "Mauritania" : "Mauritania",
    "Malawi" : "Malawi",
    "Mexico" : "Mexico",
    "Malaysia" : "Malaysia",
    "Mozambique" : "Mozambique",
    "Namibia" : "Namibia",
    "New Caledonia" : "New Caledonia",
    "Niger" : "Niger",
    "Nigeria" : "Nigeria",
    "Nicaragua" : "Nicaragua",
    "Netherlands" : "Netherlands",
    "Norway" : "Norway",
    "Nepal" : "Nepal",
    "New Zealand" : "New Zealand",
    "Oman" : "Oman",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "Papua New Guinea" : "Papua New Guinea",
    "Philippines" : "Philippines",
    "Pakistan" : "Pakistan",
    "Poland" : "Poland",
    "Puerto Rico" : "Puerto Rico",
    "Portugal" : "Portugal",
    "Paraguay" : "Paraguay",
    "Qatar" : "Qatar",
    "Romania" : "Romania",
    "Serbia" : "Serbia",
    "Russia" : "Russia",
    "Rwanda" : "Rwanda",
    "Saudi Arabia" : "Saudi Arabia",
    "Solomon Islands" : "Solomon Islands",
    "Sudan" : "Sudan",
    "Sweden" : "Sweden",
    "Singapore" : "Singapore",
    "Slovenia" : "Slovenia",
    "Slovakia" : "Slovakia",
    "Sierra Leone" : "Sierra Leone",
    "Senegal" : "Senegal",
    "Somalia" : "Somalia",
    "Suriname" : "Suriname",
    "South Sudan" : "South Sudan",
    "El Salvador" : "El Salvador",
    "Syria" : "Syria",
    "Swaziland" : "Swaziland",
    "Chad" : "Chad",
    "Fr. S. Antarctic Lands" : "Fr. S. Antarctic Lands",
    "Togo" : "Togo",
    "Thailand" : "Thailand",
    "Tajikistan" : "Tajikistan",
    "Timor-Leste" : "Timor-Leste",
    "Turkmenistan" : "Turkmenistan",
    "Tunisia" : "Tunisia",
    "Turkey" : "Turkey",
    "Trinidad and Tobago" : "Trinidad and Tobago",
    "Taiwan" : "Taiwan",
    "Tanzania" : "Tanzania",
    "Ukraine" : "Ukraine",
    "Uganda" : "Uganda",
    "United States" : "United States",
    "Uruguay" : "Uruguay",
    "Uzbekistan" : "Uzbekistan",
    "Venezuela" : "Venezuela",
    "Vietnam" : "Vietnam",
    "Vanuatu" : "Vanuatu",
    "Yemen" : "Yemen",
    "South Africa" : "South Africa",
    "Zambia" : "Zambia",
    "Zimbabwe" : "Zimbabwe",
    "Your Nextcloud account" : "Twoje konto Nextcloud",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "Twoje dane reprezentują Ciebie, które mogą być w łatwy sposób nadużywane. W Nextcloud wierzymy, że masz prawo decydować o tym, co dzieje się z Twoimi danymi. Nextcloud chroni Twoje prawa zgodnie z definicją w User Data Manifesto!",
    "User Data Manifesto 2.0" : "User Data Manifesto 2.0",
    "Defining basic rights for people to control their own data in the internet age" : "Określenie podstawowych praw do kontroli własnych danych w dobie internetu",
    "Control" : "Kontrola",
    "over user data access" : "dostęp do danych użytkownika",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "Dane jawnie i dobrowolnie przesłane przez użytkownika powinny być pod ostateczną kontrolą użytkownika. Użytkownicy powinni mieć możliwość decydowania, komu przyznać bezpośredni dostęp do swoich danych oraz jakie pozwolenia powinny zostać przyznane.",
    "Knowledge" : "Wiedza",
    "of how the data is stored" : "sposób przechowywania danych",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "Kiedy dane są przesyłane do określonego usługodawcy, użytkownicy powinni być informowani o tym, gdzie dany dostawca usług przechowuje dane, jak długo, w jakiej jurysdykcji działa dany usługodawca, i które przepisy mają zastosowanie.",
    "Freedom" : "Dowolność",
    "to choose a platform" : "wybór platformy",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "Użytkownicy powinni mieć zawsze możliwość wyodrębnienia swoich danych z usługi w dowolnym czasie, nie mając możliwości zablokowania dostawcy. Aby to zagwarantować, niezbędne są otwarte standardy formatów i protokołów.",
    "Learn more ↗" : "Dowiedz się więcej ↗",
    "Where is your data?" : "Gdzie są Twoje dane?",
    "Who has access to your data?" : "Kto ma dostęp do Twoich danych?",
    "Administrators" : "Administratorzy",
    "People you shared with" : "Osoby, którym udostępniasz",
    "Privacy policy" : "Polityka prywatności",
    "Read the privacy policy." : "Przeczytaj politykę prywatności.",
    "Encryption" : "Szyfrowanie"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
